DoubleMarginLoss
================

.. currentmodule:: pykeen.losses

.. autoclass:: DoubleMarginLoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DoubleMarginLoss.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~DoubleMarginLoss.forward
      ~DoubleMarginLoss.process_lcwa_scores
      ~DoubleMarginLoss.process_slcwa_scores
      ~DoubleMarginLoss.resolve_margin

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: process_lcwa_scores
   .. automethod:: process_slcwa_scores
   .. automethod:: resolve_margin
